# Aerospace Chatbot
Aerospace discipline-specific chatbots and AI tools.
Help docs here: https://aerospace-chatbot.readthedocs.io/en/latest/

## Deployments
See https://aerospace-chatbot.readthedocs.io/en/latest/help/deployments.html for details.

### Aerospace Mechanism Chatbot
> **Note:** For access to this demo, please reach out to [dsm@danmueller.pro](mailto:dsm@danmueller.pro) for an invite link.

There is a deployment of Aerospace Chatbot, loaded with Aerospace Mecahnism Symposia papers going back to 2020 available as a demo. 